@@ -106,10 +106,8 @@ Drupal.tableDrag = function (table, tableSettings) {
 
   // Add mouse bindings to the document. The self variable is passed along
   // as event handlers do not have direct access to the tableDrag object.
-  $(document).bind('mousemove pointermove', function (event) { return self.dragRow(event, self); });
-  $(document).bind('mouseup pointerup', function (event) { return self.dropRow(event, self); });
-  $(document).bind('touchmove', function (event) { return self.dragRow(event.originalEvent.touches[0], self); });
-  $(document).bind('touchend', function (event) { return self.dropRow(event.originalEvent.touches[0], self); });
+  $(document).bind('mousemove', function (event) { return self.dragRow(event, self); });
+  $(document).bind('mouseup', function (event) { return self.dropRow(event, self); });
 };
 
 /**
@@ -276,10 +274,7 @@ Drupal.tableDrag.prototype.makeDraggable = function (item) {
   });
 
   // Add the mousedown action for the handle.
-  handle.bind('mousedown touchstart pointerdown', function (event) {
-    if (event.originalEvent.type == "touchstart") {
-      event = event.originalEvent.touches[0];
-    }
+  handle.mousedown(function (event) {
     // Create a new dragObject recording the event information.
     self.dragObject = {};
     self.dragObject.initMouseOffset = self.getMouseOffset(item, event);
